@@ -4,14 +4,14 @@ from typing import Optional
 class ReqIFSpecRelationType:
     def __init__(  # pylint: disable=too-many-arguments
         self,
-        is_self_closed: bool,
-        description: Optional[str],
         identifier: str,
-        last_change: Optional[str],
-        long_name: str,
+        description: Optional[str] = None,
+        last_change: Optional[str] = None,
+        long_name: Optional[str] = None,
+        is_self_closed: bool = True,
     ):
-        self.is_self_closed: bool = is_self_closed
-        self.description: Optional[str] = description
         self.identifier: str = identifier
+        self.description: Optional[str] = description
         self.last_change: Optional[str] = last_change
-        self.long_name: str = long_name
+        self.long_name: Optional[str] = long_name
+        self.is_self_closed: bool = is_self_closed
