@@ -216,7 +216,6 @@ class SpecObjectTypeParser:
                             default_value = stringify_namespaced_children(
                                 xml_values
                             )
-                            default_value = default_value.strip()
                         else:
                             raise NotImplementedError
                 elif (
@@ -413,6 +412,7 @@ class SpecObjectTypeParser:
             output += "              <DEFAULT-VALUE/>\n"
             return output
         if attribute.attribute_type == SpecObjectAttributeType.ENUMERATION:
+            assert attribute.default_value_definition_ref is not None, attribute
             output += (
                 "              <DEFAULT-VALUE>\n"
                 f"                "
@@ -431,6 +431,7 @@ class SpecObjectTypeParser:
                 "              </DEFAULT-VALUE>\n"
             )
         elif attribute.attribute_type == SpecObjectAttributeType.XHTML:
+            assert attribute.default_value_definition_ref is not None, attribute
             output += (
                 "              <DEFAULT-VALUE>\n"
                 "                <ATTRIBUTE-VALUE-XHTML>\n"
@@ -439,13 +440,13 @@ class SpecObjectTypeParser:
                 f"{attribute.default_value_definition_ref}"
                 f"</ATTRIBUTE-DEFINITION-XHTML-REF>\n"
                 "                  </DEFINITION>\n"
-                "                  <THE-VALUE>\n"
-                f"                    {attribute.default_value}\n"
-                "                  </THE-VALUE>\n"
+                "                  <THE-VALUE>"
+                f"{attribute.default_value}</THE-VALUE>\n"
                 "                </ATTRIBUTE-VALUE-XHTML>\n"
                 "              </DEFAULT-VALUE>\n"
             )
         elif attribute.attribute_type == SpecObjectAttributeType.BOOLEAN:
+            assert attribute.default_value_definition_ref is not None, attribute
             output += (
                 "              <DEFAULT-VALUE>\n"
                 f"                <ATTRIBUTE-VALUE-BOOLEAN "
